orangefs: Remove ``aligned'' upcall and downcall length macros.

There was previously MAX_ALIGNED_DEV_REQ_(UP|DOWN)SIZE macros which
evaluated to MAX_DEV_REQ_(UP|DOWN)SIZE+8. As it is unclear what this is
for, other than creating a situation where we accept more data than we
can parse, it is removed.

Signed-off-by: Mike Marshall <hubcap@omnibond.com>
Signed-off-by: Martin Brandenburg <martin@omnibond.com>
diff --git a/fs/orangefs/devorangefs-req.c b/fs/orangefs/devorangefs-req.c
index 4d7ab7c..5a9c53e 100644
--- a/fs/orangefs/devorangefs-req.c
+++ b/fs/orangefs/devorangefs-req.c
@@ -120,10 +120,10 @@
 	}
 
 	/*
 	 * The client will do an ioctl to find MAX_ALIGNED_DEV_REQ_UPSIZE, then
 	 * always read with that size buffer.
 	 */
-	if (count != MAX_ALIGNED_DEV_REQ_UPSIZE) {
+	if (count != MAX_DEV_REQ_UPSIZE) {
 		gossip_err("orangefs: client-core tried to read wrong size\n");
 		return -EINVAL;
 	}
@@ -226,7 +226,7 @@
 		goto error;
 
 	/* The client only asks to read one size buffer. */
-	return MAX_ALIGNED_DEV_REQ_UPSIZE;
+	return MAX_DEV_REQ_UPSIZE;
 error:
 	/*
 	 * We were unable to copy the op data to the client. Put the op back in
@@ -258,7 +258,7 @@
 	void *buffer = NULL;
 	void *ptr = NULL;
 	unsigned long i = 0;
-	int num_remaining = MAX_ALIGNED_DEV_REQ_DOWNSIZE;
+	int num_remaining = MAX_DEV_REQ_DOWNSIZE;
 	int ret = 0;
 	/* num elements in iovec without trailer */
 	int notrailer_count = 4;
@@ -661,8 +661,8 @@
 static long dispatch_ioctl_command(unsigned int command, unsigned long arg)
 {
 	static __s32 magic = ORANGEFS_DEVREQ_MAGIC;
-	static __s32 max_up_size = MAX_ALIGNED_DEV_REQ_UPSIZE;
-	static __s32 max_down_size = MAX_ALIGNED_DEV_REQ_DOWNSIZE;
+	static __s32 max_up_size = MAX_DEV_REQ_UPSIZE;
+	static __s32 max_down_size = MAX_DEV_REQ_DOWNSIZE;
 	struct ORANGEFS_dev_map_desc user_desc;
 	int ret = 0;
 	struct dev_mask_info_s mask_info = { 0 };
@@ -120,10 +120,10 @@
 
 	/*
-	 * The client will do an ioctl to find MAX_ALIGNED_DEV_REQ_UPSIZE, then
+	 * The client will do an ioctl to find MAX_DEV_REQ_UPSIZE, then
 	 * always read with that size buffer.
 	 */